@@ -1,10 +1,7 @@
-﻿# -*- coding: utf-8 -*-
-from __future__ import print_function, unicode_literals
-
 import locale
 import os
 import re
-from codecs import open
+from posixpath import join as posix_join
 
 from pelican.settings import DEFAULT_CONFIG
 from pelican.tests.support import (mute, skipIfNoExecutable, temporary_folder,
@@ -43,7 +40,7 @@ class TestBloggerXmlImporter(unittest.TestCase):
 
     def setUp(self):
         self.old_locale = locale.setlocale(locale.LC_ALL)
-        locale.setlocale(locale.LC_ALL, str('C'))
+        locale.setlocale(locale.LC_ALL, 'C')
         self.posts = blogger2fields(BLOGGER_XML_SAMPLE)
 
     def tearDown(self):
@@ -92,7 +89,7 @@ class TestWordpressXmlImporter(unittest.TestCase):
 
     def setUp(self):
         self.old_locale = locale.setlocale(locale.LC_ALL)
-        locale.setlocale(locale.LC_ALL, str('C'))
+        locale.setlocale(locale.LC_ALL, 'C')
         self.posts = wp2fields(WORDPRESS_XML_SAMPLE)
         self.custposts = wp2fields(WORDPRESS_XML_SAMPLE, True)
 
@@ -102,8 +99,8 @@ class TestWordpressXmlImporter(unittest.TestCase):
     def test_ignore_empty_posts(self):
         self.assertTrue(self.posts)
         for (title, content, fname, date, author,
-             categ, tags, status, kind, format) in self.posts:
-                self.assertTrue(title.strip())
+                categ, tags, status, kind, format) in self.posts:
+            self.assertTrue(title.strip())
 
     def test_recognise_page_kind(self):
         """ Check that we recognise pages in wordpress, as opposed to posts """
@@ -111,9 +108,9 @@ class TestWordpressXmlImporter(unittest.TestCase):
         # Collect (title, filename, kind) of non-empty posts recognised as page
         pages_data = []
         for (title, content, fname, date, author,
-             categ, tags, status, kind, format) in self.posts:
-                if kind == 'page':
-                    pages_data.append((title, fname))
+                categ, tags, status, kind, format) in self.posts:
+            if kind == 'page':
+                pages_data.append((title, fname))
         self.assertEqual(2, len(pages_data))
         self.assertEqual(('Page', 'contact'), pages_data[0])
         self.assertEqual(('Empty Page', 'empty'), pages_data[1])
@@ -140,7 +137,7 @@ class TestWordpressXmlImporter(unittest.TestCase):
         index = 0
         for post in test_posts:
             name = post[2]
-            category = slugify(post[5][0], regex_subs=subs)
+            category = slugify(post[5][0], regex_subs=subs, preserve_case=True)
             name += '.md'
             filename = os.path.join(category, name)
             out_name = fnames[index]
@@ -151,22 +148,22 @@ class TestWordpressXmlImporter(unittest.TestCase):
         self.assertTrue(self.posts)
         pages_data = []
         for (title, content, fname, date, author, categ,
-             tags, status, kind, format) in self.posts:
-                if kind == 'page' or kind == 'article':
-                    pass
-                else:
-                    pages_data.append((title, fname))
+                tags, status, kind, format) in self.posts:
+            if kind == 'page' or kind == 'article':
+                pass
+            else:
+                pages_data.append((title, fname))
         self.assertEqual(0, len(pages_data))
 
     def test_recognise_custom_post_type(self):
         self.assertTrue(self.custposts)
         cust_data = []
         for (title, content, fname, date, author, categ,
-             tags, status, kind, format) in self.custposts:
-                if kind == 'article' or kind == 'page':
-                    pass
-                else:
-                    cust_data.append((title, kind))
+                tags, status, kind, format) in self.custposts:
+            if kind == 'article' or kind == 'page':
+                pass
+            else:
+                cust_data.append((title, kind))
         self.assertEqual(3, len(cust_data))
         self.assertEqual(
             ('A custom post in category 4', 'custom1'),
@@ -217,7 +214,7 @@ class TestWordpressXmlImporter(unittest.TestCase):
         for post in test_posts:
             name = post[2]
             kind = post[8]
-            category = slugify(post[5][0], regex_subs=subs)
+            category = slugify(post[5][0], regex_subs=subs, preserve_case=True)
             name += '.md'
             filename = os.path.join(kind, category, name)
             out_name = fnames[index]
@@ -284,9 +281,9 @@ class TestWordpressXmlImporter(unittest.TestCase):
 
     def test_decode_wp_content(self):
         """ Check that we can decode a wordpress content string."""
-        with open(WORDPRESS_ENCODED_CONTENT_SAMPLE, 'r') as encoded_file:
+        with open(WORDPRESS_ENCODED_CONTENT_SAMPLE) as encoded_file:
             encoded_content = encoded_file.read()
-            with open(WORDPRESS_DECODED_CONTENT_SAMPLE, 'r') as decoded_file:
+            with open(WORDPRESS_DECODED_CONTENT_SAMPLE) as decoded_file:
                 decoded_content = decoded_file.read()
                 self.assertEqual(
                     decode_wp_content(encoded_content, br=False),
@@ -407,7 +404,7 @@ class TestBuildHeader(unittest.TestCase):
 class TestWordpressXMLAttachements(unittest.TestCase):
     def setUp(self):
         self.old_locale = locale.setlocale(locale.LC_ALL)
-        locale.setlocale(locale.LC_ALL, str('C'))
+        locale.setlocale(locale.LC_ALL, 'C')
         self.attachments = get_attachments(WORDPRESS_XML_SAMPLE)
 
     def tearDown(self):
@@ -452,5 +449,5 @@ class TestWordpressXMLAttachements(unittest.TestCase):
             self.assertEqual(1, len(locations))
             directory = locations[0]
             self.assertTrue(
-                directory.endswith(os.path.join('content', 'article.rst')),
+                directory.endswith(posix_join('content', 'article.rst')),
                 directory)
