@@ -1,21 +1,10 @@
-# -*- coding: utf-8 -*-
-from __future__ import print_function, unicode_literals
-
 import os
-
-import six
+from unittest.mock import patch
 
 from pelican import readers
 from pelican.tests.support import get_settings, unittest
 from pelican.utils import SafeDatetime
 
-try:
-    from unittest.mock import patch
-except ImportError:
-    try:
-        from mock import patch
-    except ImportError:
-        patch = False
 
 CUR_DIR = os.path.dirname(__file__)
 CONTENT_PATH = os.path.join(CUR_DIR, 'content')
@@ -29,6 +18,7 @@ class ReaderTest(unittest.TestCase):
 
     def read_file(self, path, **kwargs):
         # Isolate from future API changes to readers.read_file
+
         r = readers.Readers(settings=get_settings(**kwargs))
         return r.read_file(base_path=CONTENT_PATH, path=path)
 
@@ -64,8 +54,7 @@ class TestAssertDictHasSubset(ReaderTest):
         self.assertDictHasSubset(self.dictionary, self.dictionary)
 
     def test_fail_not_set(self):
-        six.assertRaisesRegex(
-            self,
+        self.assertRaisesRegex(
             AssertionError,
             r'Expected.*key-c.*to have value.*val-c.*but was not in Dict',
             self.assertDictHasSubset,
@@ -73,8 +62,7 @@ class TestAssertDictHasSubset(ReaderTest):
             {'key-c': 'val-c'})
 
     def test_fail_wrong_val(self):
-        six.assertRaisesRegex(
-            self,
+        self.assertRaisesRegex(
             AssertionError,
             r'Expected .*key-a.* to have value .*val-b.* but was .*val-a.*',
             self.assertDictHasSubset,
@@ -88,7 +76,50 @@ class DefaultReaderTest(ReaderTest):
         with self.assertRaises(TypeError):
             self.read_file(path='article_with_metadata.unknownextension')
 
-    @unittest.skipUnless(patch, 'Needs Mock module')
+    def test_readfile_path_metadata_implicit_dates(self):
+        test_file = 'article_with_metadata_implicit_dates.html'
+        page = self.read_file(path=test_file, DEFAULT_DATE='fs')
+        expected = {
+            'date': SafeDatetime.fromtimestamp(
+                os.stat(_path(test_file)).st_mtime),
+            'modified': SafeDatetime.fromtimestamp(
+                os.stat(_path(test_file)).st_mtime)
+        }
+
+        self.assertDictHasSubset(page.metadata, expected)
+
+    def test_readfile_path_metadata_explicit_dates(self):
+        test_file = 'article_with_metadata_explicit_dates.html'
+        page = self.read_file(path=test_file, DEFAULT_DATE='fs')
+        expected = {
+            'date': SafeDatetime(2010, 12, 2, 10, 14),
+            'modified': SafeDatetime(2010, 12, 31, 23, 59)
+        }
+
+        self.assertDictHasSubset(page.metadata, expected)
+
+    def test_readfile_path_metadata_implicit_date_explicit_modified(self):
+        test_file = 'article_with_metadata_implicit_date_explicit_modified.html'
+        page = self.read_file(path=test_file, DEFAULT_DATE='fs')
+        expected = {
+            'date': SafeDatetime.fromtimestamp(
+                os.stat(_path(test_file)).st_mtime),
+            'modified': SafeDatetime(2010, 12, 2, 10, 14),
+        }
+
+        self.assertDictHasSubset(page.metadata, expected)
+
+    def test_readfile_path_metadata_explicit_date_implicit_modified(self):
+        test_file = 'article_with_metadata_explicit_date_implicit_modified.html'
+        page = self.read_file(path=test_file, DEFAULT_DATE='fs')
+        expected = {
+            'date': SafeDatetime(2010, 12, 2, 10, 14),
+            'modified': SafeDatetime.fromtimestamp(
+                os.stat(_path(test_file)).st_mtime)
+        }
+
+        self.assertDictHasSubset(page.metadata, expected)
+
     def test_find_empty_alt(self):
         with patch('pelican.readers.logger') as log_mock:
             content = ['<img alt="" src="test-image.png" width="300px" />',
@@ -97,9 +128,9 @@ class DefaultReaderTest(ReaderTest):
             for tag in content:
                 readers.find_empty_alt(tag, '/test/path')
                 log_mock.warning.assert_called_with(
-                    u'Empty alt attribute for image %s in %s',
-                    u'test-image.png',
-                    u'/test/path',
+                    'Empty alt attribute for image %s in %s',
+                    'test-image.png',
+                    '/test/path',
                     extra={'limit_msg':
                            'Other images have empty alt attributes'}
                 )
@@ -125,6 +156,24 @@ class RstReaderTest(ReaderTest):
 
         self.assertDictHasSubset(page.metadata, expected)
 
+    def test_article_with_capitalized_metadata(self):
+        page = self.read_file(path='article_with_capitalized_metadata.rst')
+        expected = {
+            'category': 'yeah',
+            'author': 'Alexis Métaireau',
+            'title': 'This is a super article !',
+            'summary': '<p class="first last">Multi-line metadata should be'
+                       ' supported\nas well as <strong>inline'
+                       ' markup</strong> and stuff to &quot;typogrify'
+                       '&quot;...</p>\n',
+            'date': SafeDatetime(2010, 12, 2, 10, 14),
+            'modified': SafeDatetime(2010, 12, 2, 10, 20),
+            'tags': ['foo', 'bar', 'foobar'],
+            'custom_field': 'http://notmyidea.org',
+        }
+
+        self.assertDictHasSubset(page.metadata, expected)
+
     def test_article_with_filename_metadata(self):
         page = self.read_file(
             path='2012-11-29_rst_w_filename_meta#foo-bar.rst',
@@ -273,6 +322,38 @@ class RstReaderTest(ReaderTest):
         }
         self.assertDictHasSubset(page.metadata, expected)
 
+    def test_article_extra_path_metadata_recurse(self):
+        parent = "TestCategory"
+        notparent = "TestCategory/article"
+        path = "TestCategory/article_without_category.rst"
+
+        epm = {
+            parent: {'epmr_inherit': parent,
+                     'epmr_override': parent, },
+            notparent: {'epmr_bogus': notparent},
+            path:   {'epmr_override': path, },
+            }
+        expected_metadata = {
+            'epmr_inherit': parent,
+            'epmr_override': path,
+            }
+
+        page = self.read_file(path=path, EXTRA_PATH_METADATA=epm)
+        self.assertDictHasSubset(page.metadata, expected_metadata)
+
+        # Make sure vars aren't getting "inherited" by mistake...
+        path = "article.rst"
+        page = self.read_file(path=path, EXTRA_PATH_METADATA=epm)
+        for k in expected_metadata.keys():
+            self.assertNotIn(k, page.metadata)
+
+        # Same, but for edge cases where one file's name is a prefix of
+        # another.
+        path = "TestCategory/article_without_category.rst"
+        page = self.read_file(path=path, EXTRA_PATH_METADATA=epm)
+        for k in epm[notparent].keys():
+            self.assertNotIn(k, page.metadata)
+
     def test_typogrify(self):
         # if nothing is specified in the settings, the content should be
         # unmodified
@@ -413,9 +494,43 @@ class RstReaderTest(ReaderTest):
     def test_parse_error(self):
         # Verify that it raises an Exception, not nothing and not SystemExit or
         # some such
-        with six.assertRaisesRegex(self, Exception, "underline too short"):
+        with self.assertRaisesRegex(Exception, "underline too short"):
             self.read_file(path='../parse_error/parse_error.rst')
 
+    def test_typogrify_dashes_config(self):
+        # Test default config
+        page = self.read_file(
+            path='article_with_typogrify_dashes.rst',
+            TYPOGRIFY=True,
+            TYPOGRIFY_DASHES='default')
+        expected = "<p>One: -; Two: &#8212;; Three:&nbsp;&#8212;-</p>\n"
+        expected_title = "One -, two &#8212;, three &#8212;-&nbsp;dashes!"
+
+        self.assertEqual(page.content, expected)
+        self.assertEqual(page.title, expected_title)
+
+        # Test 'oldschool' variant
+        page = self.read_file(
+            path='article_with_typogrify_dashes.rst',
+            TYPOGRIFY=True,
+            TYPOGRIFY_DASHES='oldschool')
+        expected = "<p>One: -; Two: &#8211;; Three:&nbsp;&#8212;</p>\n"
+        expected_title = "One -, two &#8211;, three &#8212;&nbsp;dashes!"
+
+        self.assertEqual(page.content, expected)
+        self.assertEqual(page.title, expected_title)
+
+        # Test 'oldschool_inverted' variant
+        page = self.read_file(
+            path='article_with_typogrify_dashes.rst',
+            TYPOGRIFY=True,
+            TYPOGRIFY_DASHES='oldschool_inverted')
+        expected = "<p>One: -; Two: &#8212;; Three:&nbsp;&#8211;</p>\n"
+        expected_title = "One -, two &#8212;, three &#8211;&nbsp;dashes!"
+
+        self.assertEqual(page.content, expected)
+        self.assertEqual(page.title, expected_title)
+
 
 @unittest.skipUnless(readers.Markdown, "markdown isn't installed")
 class MdReaderTest(ReaderTest):
@@ -448,7 +563,10 @@ class MdReaderTest(ReaderTest):
         self.assertDictHasSubset(metadata, expected)
 
     def test_article_with_footnote(self):
-        reader = readers.MarkdownReader(settings=get_settings())
+        settings = get_settings()
+        ec = settings['MARKDOWN']['extension_configs']
+        ec['markdown.extensions.footnotes'] = {'SEPARATOR': '-'}
+        reader = readers.MarkdownReader(settings)
         content, metadata = reader.read(
             _path('article_with_markdown_and_footnote.md'))
         expected_content = (
@@ -615,6 +733,19 @@ class MdReaderTest(ReaderTest):
         }
         self.assertDictHasSubset(metadata, expected)
 
+    def test_metadata_not_parsed_for_metadata(self):
+        settings = get_settings()
+        settings['FORMATTED_FIELDS'] = ['summary']
+
+        reader = readers.MarkdownReader(settings=settings)
+        content, metadata = reader.read(
+            _path('article_with_markdown_and_nested_metadata.md'))
+        expected = {
+            'title': 'Article with markdown and nested summary metadata',
+            'summary': '<p>Test: This metadata value looks like metadata</p>',
+        }
+        self.assertDictHasSubset(metadata, expected)
+
     def test_empty_file(self):
         reader = readers.MarkdownReader(settings=get_settings())
         content, metadata = reader.read(
@@ -631,6 +762,57 @@ class MdReaderTest(ReaderTest):
         self.assertEqual(metadata, {})
         self.assertEqual(content, '')
 
+    def test_typogrify_dashes_config(self):
+        # Test default config
+        page = self.read_file(
+            path='article_with_typogrify_dashes.md',
+            TYPOGRIFY=True,
+            TYPOGRIFY_DASHES='default')
+        expected = "<p>One: -; Two: &#8212;; Three:&nbsp;&#8212;-</p>"
+        expected_title = "One -, two &#8212;, three &#8212;-&nbsp;dashes!"
+
+        self.assertEqual(page.content, expected)
+        self.assertEqual(page.title, expected_title)
+
+        # Test 'oldschool' variant
+        page = self.read_file(
+            path='article_with_typogrify_dashes.md',
+            TYPOGRIFY=True,
+            TYPOGRIFY_DASHES='oldschool')
+        expected = "<p>One: -; Two: &#8211;; Three:&nbsp;&#8212;</p>"
+        expected_title = "One -, two &#8211;, three &#8212;&nbsp;dashes!"
+
+        self.assertEqual(page.content, expected)
+        self.assertEqual(page.title, expected_title)
+
+        # Test 'oldschool_inverted' variant
+        page = self.read_file(
+            path='article_with_typogrify_dashes.md',
+            TYPOGRIFY=True,
+            TYPOGRIFY_DASHES='oldschool_inverted')
+        expected = "<p>One: -; Two: &#8212;; Three:&nbsp;&#8211;</p>"
+        expected_title = "One -, two &#8212;, three &#8211;&nbsp;dashes!"
+
+        self.assertEqual(page.content, expected)
+        self.assertEqual(page.title, expected_title)
+
+    def test_metadata_has_no_discarded_data(self):
+        md_filename = 'article_with_markdown_and_empty_tags.md'
+
+        r = readers.Readers(cache_name='cache', settings=get_settings(
+            CACHE_CONTENT=True))
+        page = r.read_file(base_path=CONTENT_PATH, path=md_filename)
+
+        __, cached_metadata = r.get_cached_data(
+            _path(md_filename), (None, None))
+
+        expected = {
+            'title': 'Article with markdown and empty tags'
+        }
+        self.assertEqual(cached_metadata, expected)
+        self.assertNotIn('tags', page.metadata)
+        self.assertDictHasSubset(page.metadata, expected)
+
 
 class HTMLReaderTest(ReaderTest):
     def test_article_with_comments(self):
@@ -729,3 +911,10 @@ class HTMLReaderTest(ReaderTest):
         }
 
         self.assertDictHasSubset(page.metadata, expected)
+
+    def test_article_with_inline_svg(self):
+        page = self.read_file(path='article_with_inline_svg.html')
+        expected = {
+            'title': 'Article with an inline SVG',
+        }
+        self.assertDictHasSubset(page.metadata, expected)
